import {EventEmitter2} from 'eventemitter2';
import * as Immutable from 'immutable';
import {Observable} from 'rxjs';

import {FileUpload} from '../file-sharing/FileUpload';

import {ChatMessage} from './ChatMessage';
import {ChatParticipantRole} from './ChatParticipantRole';
import {ChatParticipantState} from './ChatParticipantState';
import {ChatType} from './ChatType';

export class Chat {
	emitter: EventEmitter2;
	addParticipant(participant: string): Promise<void>;
	archive(): Promise<void>;
	cancelPendingMessage(message: ChatMessage): Promise<void>;
	delete(): Promise<void>;
	expelParticipant(participant: string): Promise<void>;
	fetch(minimum?: number): Promise<void>;
	getFileMessages(): Immutable.List<ChatMessage>;
	readonly firstUnreadMessage: ChatMessage;
	getFirstUnreadMessage(): ChatMessage;
	getFirstUnreadMessage$(): Observable<ChatMessage>;
	getId(): string;
	readonly messages: Immutable.List<ChatMessage>;
	getMessages(): Immutable.List<ChatMessage>;
	getMessages$(): Observable<Immutable.List<ChatMessage>>;
	getName(): string;
	getParticipants(): Immutable.Map<string, ChatParticipantRole>;
	getPendingMessages(): Immutable.List<ChatMessage>;
	getRemoteParticipants(): Immutable.Map<string, ChatParticipantState>;
	getRole(): ChatParticipantRole;
	getSubject(): string;
	getType(): ChatType;
	getUnreadMessageCount$(): Observable<number>;
	getUnreadMessageCount(): number;
	leave(): Promise<void>;
	resetUnreadMessageCount(): Promise<void>;
	sendFile(file: File): Promise<FileUpload>;
	sendText(text: string): Promise<void>;
	setParticipantRole(participant: string, role: ChatParticipantRole): Promise<void>;
	setState(state: ChatParticipantState): Promise<void>;
	setSubject(subject: string): Promise<void>;
	isOldestMessageRecovered(): boolean;
	sync(): Promise<void>;
}
