import { User } from '../session/User';
import { Chat } from './Chat';
declare type SupportChatParticipant = Pick<User, 'domain' | 'id' | 'username'>;
export interface SupportChatService {
    leaveSupportChat(id: string): Promise<void>;
    transferSupportChat(id: string, destination: SupportChatParticipant): Promise<void>;
}
export interface SupportChat extends Chat {
}
export declare class SupportChat {
    private supportChatId;
    private chatService;
    private constructor();
    static create(supportChatId: string, chatService: SupportChatService, chat: Chat): SupportChat;
    /**
     * Leaves the current Support Chat
     *
     * If leaving participant is the chat's agent, the support chat is finished.
     *
     * @return {Promise<void>}
     */
    leave(): Promise<void>;
    /**
     * Transfers the current Support Chat to another agent
     *
     * Changes the agent who is assigned to this support chat.  The backend
     * will generate an XMPP invitation to that destination agent.
     *
     * @param {object} destination The agent we want to transfer this chat to
     * @param {string} destination.id The ID of the agent
     * @param {string} destination.username The username of the agent
     * @param {string} destination domain The domain of the agent
     *
     * @return {Promise<void>}
     */
    transfer(destination: SupportChatParticipant): Promise<void>;
}
export {};
