import { Observable } from 'rxjs';
import { ConferenceLogService } from '../wac-proxy/wac-stack/conference-log/ConferenceLogService';
import { ConferenceLogEntry } from './ConferenceLogEntry';
/**
 * This class allows access to the conference log. To obtain an instance of the
 * class {@link ConferenceManager#getConferenceLog} method must be used.
 */
export declare class ConferenceLog {
    private conferenceLogService;
    private ownId;
    entries$: Observable<readonly ConferenceLogEntry[]>;
    missedCallsCount$: Observable<number>;
    private entriesSubject;
    private missedCalls$;
    constructor(conferenceLogService: ConferenceLogService, ownId: string);
    /**
     * Fetches more conference log entries.
     * @param [limit=10] The number of new entries to be fetched at most
     * @returns When resolved, the update was completed and get the new conference log objects.
     * The return value is deprecated and will be remove in the future
     */
    fetch(limit?: number): Promise<readonly ConferenceLogEntry[]>;
    /**
     * Marks as read all the missed calls for this user
     */
    readMissedCalls(): Promise<void>;
    private getLastEntryTimestamp;
}
