import { Observable } from 'rxjs';
import { UserRepository } from '../users/UserRepository';
import { ContactService } from '../wac-proxy/wac-stack/contact/ContactService';
import { Contact } from './Contact';
/**
 * Allows retrieving, updating and creating contacts. An instance of this class
 * must be obtained using {@link Session.getContactRepository}
 */
export declare class ContactRepository {
    private contactService;
    private userRepository;
    /**
     * Allows access to the list with every contact
     */
    readonly contacts$: Observable<readonly Contact[]>;
    constructor(contactService: ContactService, userRepository: UserRepository);
    private getActions;
    /**
     * Saves a contact
     * @param contact
     */
    saveContact(contact: Pick<Contact, 'emails' | 'favorite' | 'id' | 'name' | 'phones'>): Promise<void>;
    /**
     * Creates a new contact
     * @param contact
     */
    createContact(contact: Pick<Contact, 'emails' | 'favorite' | 'name' | 'phones'>): Promise<void>;
    /**
     * Deletes a contact
     * @param contact
     */
    deleteContact(contact: Pick<Contact, 'id'>): Promise<void>;
}
