/**
 * Enum with the different types of a contact
 */
export declare enum ContactType {
    /**
     * Contacts created by user themselves. They are the only contacts that can be created,
     * edited or deleted.
     */
    CONTACTS = 0,
    /**
     * Contacts representing a user of the domain. There is one contact of this type for each user
     * of a domain different of the current user.
     */
    DOMAIN = 1,
    /**
     * Contacts statically defined by system administrators.
     */
    STATIC = 2,
    /**
     * Contacts representing a group. There is one contact of this type for each group existing
     * in the current user domain.
     */
    GROUPS = 3,
    /**
     * Contacts declared inside the phonebooks associated to every group the current user is
     * included in.
     */
    PHONEBOOKS = 4,
    /**
     * Organization contacts imported from Microsoft Azure
     */
    AZURE_ORG_CONTACTS = 5
}
