import { Observable } from 'rxjs';
import { Dtmf } from '../../../../types';
import { SignalingClient } from './Client';
import { ServerAPI } from './ServerAPI';
import { RoomDto } from './dtos';
export declare class RoomsAPI extends ServerAPI {
    muteChange$: Observable<{
        userId: string;
        roomId: string;
        muted: boolean;
    }>;
    muteRequest$: Observable<{
        roomId: string;
        muted: boolean;
    }>;
    constructor(client: SignalingClient);
    /**
     * Get any room from server where user participates and return a list of Room instances
     * @throws {ErrorResponse} if server returns an error
     * @return resolved with server response.
     */
    getRooms(): Promise<unknown[]>;
    /**
     * Request a room creation on server and returns a Room instance
     * @throws {ErrorResponse} if server returns an error
     * @param record indicate if room should be recorded
     * @return resolved on success.
     */
    createRoom(record?: boolean): Promise<RoomDto>;
    /**
     * Join a meeting
     */
    joinMeeting(id: string, meetingId: string, password?: string): Promise<RoomDto>;
    /**
     * Join a quick conference
     */
    joinQuickConference(id: string, quickConferenceId: string): Promise<RoomDto>;
    /**
     * Add participants to a room
     * @throws {ErrorResponse} if server returns an error
     * @param id room identifier
     * @param participants list of user names to add to the room
     * @return resolved on success with server response.
     */
    addRoomParticipants(id: string, participants: string[]): Promise<unknown>;
    /**
     * Remove participants from a room
     * @throws {ErrorResponse} if server returns an error
     * @param id room identifier
     * @param participants list of user names to remove from the room
     * @return resolved on success with server response.
     */
    removeRoomParticipants(id: string, participants: string[]): Promise<unknown>;
    /**
     * Start recording a room
     * @throws {ErrorResponse} if server returns an error
     * @param id room identifier
     * @return resolved on success with server response.
     */
    startRecordingRoom(id: string): Promise<unknown>;
    /**
     * Stop recording a room
     * @throws {ErrorResponse} if server returns an error
     * @param id room identifier
     * @return resolved on success with server response.
     */
    stopRecordingRoom(id: string): Promise<unknown>;
    /**
     * Close a room
     * @throws {ErrorResponse} if server returns an error
     * @param id room identifier
     * @return resolved on success with server response.
     */
    leaveRoom(id: string): Promise<unknown>;
    /**
     * Send a DTMF tone
     */
    sendDtmf(sipUri: string, dtmf: Dtmf): Promise<unknown>;
    /**
     * Request a remote participant to be muted.
     * @param room The UUID of the room where the conference is taking place.
     * @param to The ID of the user to be un/muted.
     * @param requestedBy The ID of the user doing the request.
     * @param muted if true requests user to be muted, if false to be unmuted
     * @returns raw server response
     */
    muteRequest(room: string, to: string, requestedBy: string, muted?: boolean): Promise<unknown>;
    /**
     * Indicates users has mute/unmute themselves
     * @param roomId The UUID of the room where the user is being un/muted.
     * @param userId The ID of the user being un/muted.
     * @param muted Whether the user is being muted (true) or unmuted (false)
     * @returns raw server response
     */
    mute(roomId: string, userId: string, muted?: boolean): Promise<unknown>;
}
