interface Constraints {
    audio?: MediaTrackConstraints | boolean;
    video?: MediaTrackConstraints | boolean;
    screen?: MediaTrackConstraints | boolean;
}
declare global {
    interface Window {
        electronApi?: {
            openSourceSelector(): Promise<string>;
        };
    }
}
/**
 * Stop a {MediaStream} by calling 'stop' method on every track.
 *
 * @param {MediaStream} stream stream to stop
 * @return {void}
 */
export declare function stopStream(stream: MediaStream): void;
/**
 * Method that returns a {MediaStream} based on constraints provided
 * This method is needed for screen sharing when an unique stream that
 * contains audio, video and screen tracks must be obtained. Current implementation
 * has some limitations:
 *  - Require two video tracks (camera and screen) is not supported
 *  - Screen sharing is only supported on Chrome >= 72, Firefox >= 66 and Edge >= 17
 *
 * @param {Constraints} constraints audio camera and screen constraints
 * @return {Promise<MediaStream>} media stream with desired tracks
 */
export declare function getUserMediaWithMediatypes(constraints?: Constraints): Promise<MediaStream>;
export {};
