import EventEmitter from 'eventemitter3';
import { WacRequest } from './WacRequest';
interface MeetingParticipant {
    email?: string;
    phone?: string;
}
interface User {
    username: string;
    domain: string;
}
export interface ServerMeeting {
    id: string;
    language: string;
    name: string;
    participants: MeetingParticipant[];
    phone: string;
    url: string;
    user: User;
    validSince: number;
    validUntil: number;
    isPasswordProtected: boolean;
}
export interface Meeting extends Omit<ServerMeeting, 'user'> {
    creator: string;
}
export interface MeetingMutableData extends Pick<Meeting, 'name' | 'participants' | 'validSince' | 'validUntil'> {
    password: string;
}
declare type WithOptional<T, K extends keyof T> = Omit<T, K> & Partial<Pick<T, K>>;
export declare type MeetingCreationData = WithOptional<MeetingMutableData, 'password' | 'validUntil'>;
export interface ExtendedParticipantsMutableData extends Omit<MeetingMutableData, 'participants'> {
    participants: Array<MeetingParticipant & {
        sendSMS?: boolean;
    }>;
}
declare type Events = {
    create: [Meeting];
    delete: [Pick<Meeting, 'id'>];
    update: [Meeting];
};
export declare class MeetingService {
    emitter: EventEmitter<Events, any>;
    private wacRequest;
    constructor(wacRequest: WacRequest);
    private bindEventHandlers;
    private onEvent;
    get(): Promise<Meeting[]>;
    create(meetingData: MeetingCreationData, sendSms?: boolean): Promise<Meeting>;
    getById(meetingId: string): Promise<Meeting>;
    update(meetingId: string, meetingData: Partial<MeetingMutableData>, sendSms?: boolean): Promise<Meeting>;
    delete(meetingId: string): Promise<void>;
}
export {};
